about summary refs log tree commit diff
path: root/src/libsyntax/util/parser_testing.rs
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2015-01-22 06:12:46 +0000
committerbors <bors@rust-lang.org>2015-01-22 06:12:46 +0000
commit5d2056a7e3e52b2aec41662cfd960e0eafe8494c (patch)
tree24169c2dc6be5e6c80f6bc3549fb83714160723f /src/libsyntax/util/parser_testing.rs
parent6869645e86c91544b8737b89809bdf10bef536d9 (diff)
parent90af72378d9f848de78adc5003dff6b90f327b3c (diff)
downloadrust-5d2056a7e3e52b2aec41662cfd960e0eafe8494c.tar.gz
rust-5d2056a7e3e52b2aec41662cfd960e0eafe8494c.zip
Auto merge of #21473 - alexcrichton:rollup, r=alexcrichton
Diffstat (limited to 'src/libsyntax/util/parser_testing.rs')
-rw-r--r--src/libsyntax/util/parser_testing.rs11
1 files changed, 2 insertions, 9 deletions
diff --git a/src/libsyntax/util/parser_testing.rs b/src/libsyntax/util/parser_testing.rs
index 83bbff8473d..89854f5d979 100644
--- a/src/libsyntax/util/parser_testing.rs
+++ b/src/libsyntax/util/parser_testing.rs
@@ -69,13 +69,6 @@ pub fn string_to_stmt(source_str : String) -> P<ast::Stmt> {
     })
 }
 
-/// Parse a string, return a view item
-pub fn string_to_view_item (source_str : String) -> ast::ViewItem {
-    with_error_checking_parse(source_str, |p| {
-        p.parse_view_item(Vec::new())
-    })
-}
-
 /// Parse a string, return a pat. Uses "irrefutable"... which doesn't
 /// (currently) affect parsing.
 pub fn string_to_pat(source_str: String) -> P<ast::Pat> {
@@ -130,10 +123,10 @@ pub fn matches_codepattern(a : &str, b : &str) -> bool {
     }
 }
 
 /// Given a string and an index, return the first uint >= idx
 /// that is a non-ws-char or is outside of the legal range of
 /// the string.
-fn scan_for_non_ws_or_end(a : &str, idx: uint) -> uint {
+fn scan_for_non_ws_or_end(a : &str, idx: usize) -> usize {
     let mut i = idx;
     let len = a.len();
     while (i < len) && (is_whitespace(a.char_at(i))) {
@@ -130,10 +123,10 @@ pub fn matches_codepattern(a : &str, b : &str) -> bool {
 }
 
-/// Given a string and an index, return the first uint >= idx
+/// Given a string and an index, return the first usize >= idx
 /// that is a non-ws-char or is outside of the legal range of
 /// the string.